@@ -193,7 +193,7 @@ class MobileIO(object):
   def __repr__(self):
     return _state_repr('MobileIO', self)
 
-  def update(self):
+  def update(self, timeout_ms=None):
     """
     Updates the button and axis values and state. Returns ``False`` if feedback could not be received.
 
@@ -201,7 +201,7 @@ class MobileIO(object):
     :return: ``True`` on success; ``False`` otherwise
     """
     fbk = self._fbk
-    if self._group.get_next_feedback(reuse_fbk=fbk) is None:
+    if self._group.get_next_feedback(timeout_ms=timeout_ms, reuse_fbk=fbk) is None:
       return False
 
     current_button_state = self._state._buttons
@@ -355,53 +355,73 @@ class MobileIO(object):
     self._cmd.io.e.set_int(button, value)
     return self._group.send_command_with_acknowledgement(self._cmd)
 
-  def set_led_color(self, color):
+  def set_led_color(self, color, blocking=True):
     """
     Set the edge led color
 
     :param color: The color to which the edge color is set. Certain strings are recognized as colors.
-                  Reference `~hebi.GroupCommand.led` for a complete list of allowed colors.
+                  Reference :py:attr:`~hebi.GroupCommand.led` for a complete list of allowed colors.
     :type color:  int, str
 
+    :param blocking: If ``True``, block for acknowledgement from the device. Otherwise, return as quickly as possible.
+    :type blocking:  bool
+
     :rtype: bool
     :return: ``True`` if the device received the command and successfully sent an acknowledgement; ``False`` otherwise.
     """
     self._cmd.led.color = color
-    return self._group.send_command_with_acknowledgement(self._cmd)
+    if blocking:
+      return self._group.send_command_with_acknowledgement(self._cmd)
+    return self._group.send_command(self._cmd)
 
-  def set_text(self, message):
+  def set_text(self, message, blocking=True):
     """
     Append a message to the text display.
 
     :param message: The string to append to the display
     :type message:  str
 
+    :param blocking: If ``True``, block for acknowledgement from the device. Otherwise, return as quickly as possible.
+    :type blocking:  bool
+
     :rtype: bool
     :return: ``True`` if the device received the command and successfully sent an acknowledgement; ``False`` otherwise.
     """
     self._cmd.append_log = message
-    return self._group.send_command_with_acknowledgement(self._cmd)
+    if blocking:
+      return self._group.send_command_with_acknowledgement(self._cmd)
+    return self._group.send_command(self._cmd)
 
-  def clear_text(self):
+  def clear_text(self, blocking=True):
     """
     Clear the text display.
 
+    :param blocking: If ``True``, block for acknowledgement from the device. Otherwise, return as quickly as possible.
+    :type blocking:  bool
+
     :rtype: bool
     :return: ``True`` if the device received the command and successfully sent an acknowledgement; ``False`` otherwise.
     """
     self._cmd.clear_log = True
-    return self._group.send_command_with_acknowledgement(self._cmd)
+    if blocking:
+      return self._group.send_command_with_acknowledgement(self._cmd)
+    return self._group.send_command(self._cmd)
 
-  def send_vibrate(self):
+  def send_vibrate(self, blocking=True):
     """
     Send a command to vibrate the device. Note that this feature depends on device support.
     If the device does not support programmatic vibrating, then this will be a no-op.
 
+    :param blocking: If ``True``, block for acknowledgement from the device. Otherwise, return as quickly as possible.
+    :type blocking:  bool
+
     :rtype: bool
     :return: ``True`` if the device received the command and successfully sent an acknowledgement; ``False`` otherwise.
     """
     self._cmd.effort = 1
-    return self._group.send_command_with_acknowledgement(self._cmd)
+    if blocking:
+      return self._group.send_command_with_acknowledgement(self._cmd)
+    return self._group.send_command(self._cmd)
 
   def get_last_feedback(self):
     """
