@@ -337,7 +337,7 @@ class Arm(object):
     self._trajectory_start_time = self._last_time
 
     # Update aux state
-    if aux is None:
+    if aux is None or aux == []:
       self._aux = []
       self._aux_times = []
     else:
@@ -347,12 +347,13 @@ class Arm(object):
       # HACK: Figure out a better way to handle logic here...
       if len(aux_shape) == 1:
         # Will occur if the aux provided is an array of scalars (i.e., 1 aux value per waypoint)
+        first_dim = 1
         second_dim = num_waypoints
       else:
         # Will occur if the aux provided has more than 1 aux value per waypoint
+        first_dim = aux_shape[0]
         second_dim = aux_shape[1] + 1
 
-      first_dim = aux_shape[0]
       if first_dim > 0 and (second_dim == num_waypoints):
         # Update aux
         aux = np.empty((first_dim, second_dim), dtype=np.float64)
@@ -403,10 +404,11 @@ class Arm(object):
     if size == 0:
       return np.empty(0)
 
-    for i in range(size):
-      idx = i - 1
-      if t >= aux_times[idx]:
-        return aux[:, i].copy()
+    for i in reversed(range(size)):
+      if t >= aux_times[i]:
+        if i == size-1:
+          return aux[:,i].copy()
+        return aux[:, i+1].copy()
 
     return aux[:, 0].copy()
 
@@ -845,6 +847,7 @@ class Gripper(EndEffector):
     self._open_effort = open_effort
     self._command = GroupCommand(1)
     self._state = 0.0
+    self.update(self._state)
 
   @property
   def state(self):
@@ -1022,7 +1025,7 @@ class ImpedanceController(ArmPlugin):
   __slots__ = (
     '_desired_tip_fk', '_actual_tip_fk', '_jacobian_end_effector', '_cmd_pos',
     '_cmd_vel', '_fbk_pos', '_cmd_effort', '_fbk_vel', '_impedance_effort',
-    '_spring_gains', '_damper_gains', '_gains_in_end_effector_frame')
+    '_kp', '_kd', '_gains_in_end_effector_frame')
 
   def __init__(self, gains_in_end_effector_frame=False):
     self._jacobian_end_effector = None
@@ -1035,8 +1038,8 @@ class ImpedanceController(ArmPlugin):
 
     self._desired_tip_fk = np.identity(4, dtype=np.float64)
     self._actual_tip_fk = np.identity(4, dtype=np.float64)
-    self._spring_gains = np.zeros(6, dtype=np.float64)
-    self._damper_gains = np.zeros(6, dtype=np.float64)
+    self._kp = np.zeros(6, dtype=np.float64)
+    self._kd = np.zeros(6, dtype=np.float64)
     self._gains_in_end_effector_frame = gains_in_end_effector_frame
 
   @property
@@ -1061,9 +1064,10 @@ class ImpedanceController(ArmPlugin):
     self._fbk_vel = np.zeros(dof_count, dtype=np.float64)
     self._impedance_effort = np.zeros(dof_count, dtype=np.float64)
 
-  def set_spring_gains(self, x, y, z, roll, pitch, yaw):
+  def set_kp(self, x, y, z, roll, pitch, yaw):
     """
-    Sets the spring gains for the impedance controller.
+    Sets the proportional gains for the impedance controller.
+    Units are (N/m) or (Nm/rad).
 
     :type x:     float
     :type y:     float
@@ -1072,16 +1076,17 @@ class ImpedanceController(ArmPlugin):
     :type pitch: float
     :type yaw:   float
     """
-    self._spring_gains[0] = x
-    self._spring_gains[1] = y
-    self._spring_gains[2] = z
-    self._spring_gains[3] = roll
-    self._spring_gains[4] = pitch
-    self._spring_gains[5] = yaw
+    self._kp[0] = x
+    self._kp[1] = y
+    self._kp[2] = z
+    self._kp[3] = roll
+    self._kp[4] = pitch
+    self._kp[5] = yaw
 
-  def set_damper_gains(self, x, y, z, roll, pitch, yaw):
+  def set_kd(self, x, y, z, roll, pitch, yaw):
     """
-    Sets the damper gains for the impedance controller.
+    Sets the damping gains for the impedance controller.
+    Units are (N/(m/sec)) or (Nm/(rad/sec)).
 
     :type x:     float
     :type y:     float
@@ -1090,12 +1095,12 @@ class ImpedanceController(ArmPlugin):
     :type pitch: float
     :type yaw:   float
     """
-    self._damper_gains[0] = x
-    self._damper_gains[1] = y
-    self._damper_gains[2] = z
-    self._damper_gains[3] = roll
-    self._damper_gains[4] = pitch
-    self._damper_gains[5] = yaw
+    self._kd[0] = x
+    self._kd[1] = y
+    self._kd[2] = z
+    self._kd[3] = roll
+    self._kd[4] = pitch
+    self._kd[5] = yaw
 
   def update(self, arm):
     arm_cmd = arm.pending_command
@@ -1127,11 +1132,10 @@ class ImpedanceController(ArmPlugin):
     rot_error_vec = angle * axis
 
     gains_in_end_effector_frame = self._gains_in_end_effector_frame
-
     if gains_in_end_effector_frame:
-      mat = actual_tip_fk[0:3, 0:3].T
-      xyz_error[:] = mat.dot(xyz_error)
-      rot_error_vec[:] = mat.dot(rot_error_vec)
+      frame_rot = actual_tip_fk[0:3, 0:3]
+    else:
+      frame_rot = np.eye(3, dtype=np.float64)
 
     pos_error = np.empty(6, dtype=np.float64)
     pos_error[0:3] = xyz_error
@@ -1139,20 +1143,26 @@ class ImpedanceController(ArmPlugin):
     vel_error = jacobian_end_effector @ (cmd_vel - fbk_vel)
     vel_error[3:6] = 0.0
 
-    spring_wrench = np.multiply(pos_error, self._spring_gains)
+    # Calculate impedance control wrenches and appropriate joint torques
+    pos_error = self.__rotate(frame_rot.T, pos_error)
+    vel_error = self.__rotate(frame_rot.T, vel_error)
 
-    if gains_in_end_effector_frame:
-      spring_wrench[0:3] = actual_tip_fk[0:3, 0:3].dot(spring_wrench[0:3])
-      spring_wrench[3:6] = actual_tip_fk[0:3, 0:3].dot(spring_wrench[3:6])
+    wrench = np.multiply(self._kp, pos_error) + np.multiply(self._kd, vel_error)
+    wrench = self.__rotate(frame_rot, wrench)
 
-    damper_wrench = np.multiply(vel_error, self._damper_gains)
-    impedance_effort = jacobian_end_effector.T @ (spring_wrench + damper_wrench)
+    impedance_effort = jacobian_end_effector.T @ wrench
 
     cmd_eff += impedance_effort
     arm_cmd.effort = cmd_eff
 
     return True
 
+  def __rotate(self, R, vec):
+    res = np.zeros(6, dtype=np.float64)
+    res[0:3] = R.dot(vec[0:3]) # linear component
+    res[3:6] = R.dot(vec[3:6]) # rotational component
+    return vec
+
 
 class DoubledJointMirror(ArmPlugin):
   """
@@ -1190,10 +1200,10 @@ class DoubledJointMirror(ArmPlugin):
     if not np.isnan(src_eff):
       # split the effort between the 2 actuators
       new_effort = src_eff * 0.5
-      src.effort = src_eff
-      dst.effort = -src_eff
+      src.effort = new_effort
+      dst.effort = -new_effort
 
-    return self._group.send(dst)
+    return self._group.send_command(dst)
 
 
 ################################################################################
