@@ -50,7 +50,7 @@ def create_imitation_group(size):
   return _group.create_imitation_group(size)
 
 
-def load_log(file):
+def load_log(file, load=True):
   """
   Opens an existing log file.
 
@@ -76,7 +76,10 @@ def load_log(file):
   if log_file is None:
     raise IOError('file {} is not a valid log file'.format(file))
 
-  return _log_file.LogFile(log_file)
+  log = _log_file.LogFile(log_file)
+  if load:
+      log.load()
+  return log
 
 
 def plot_logs(logs, fbk_field, figure_spec=None, modules=None):
